
.. blogpost::
    :title: Why mlprodict?
    :keywords: reference, blog, post
    :date: 2017-11-30
    :categories: documentation

    What about predicting with :epkg:`scikit-learn`
    with :epkg:`C` but still training in :epkg:`Python`?
